==> scotch_5.1.8a.dfsg.orig.tar.gz: scotch-5.1.8a.dfsg/src/libscotch/vgraph_separate_gp.h <==
/* Copyright 2004,2007 ENSEIRB, INRIA & CNRS
**
** This file is part of the Scotch software package for static mapping,
** graph partitioning and sparse matrix ordering.
**
** This software is governed by the CeCILL-C license under French law
** and abiding by the rules of distribution of free software. You can
** use, modify and/or redistribute the software under the terms of the
** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
** URL: "http://www.cecill.info".
** 
** As a counterpart to the access to the source code and rights to copy,
** modify and redistribute granted by the license, users are provided
** only with a limited warranty and the software's author, the holder of
** the economic rights, and the successive licensors have only limited
** liability.
** 
** In this respect, the user's attention is drawn to the risks associated
** with loading, using, modifying and/or developing or reproducing the
** software by the user in light of its specific status of free software,
** that may mean that it is complicated to manipulate, and that also
** therefore means that it is reserved for developers and experienced
** professionals having in-depth computer knowledge. Users are therefore
** encouraged to load and test the software's suitability as regards
** their requirements in conditions enabling the security of their
** systems and/or data to be ensured and, more generally, to use and
** operate it in the same conditions as regards security.
** 
** The fact that you are presently reading this means that you have had
** knowledge of the CeCILL-C license and that you accept its terms.
*/
/************************************************************/
/**                                                        **/
/**   NAME       : vgraph_separate_gp.h                    **/
/**                                                        **/
/**   AUTHOR     : Francois PELLEGRINI                     **/
/**                                                        **/
/**   FUNCTION   : These lines are the data declaration    **/
/**                for the Gibbs, Poole, and Stockmeyer    **/
/**                graph separation algorithm.             **/
/**                                                        **/
/**   DATES      : # Version 4.0  : from : 14 may 2004     **/
/**                                 to     17 may 2004     **/
/**                                                        **/
/************************************************************/

/*
**  The type and structure definitions.
*/

/*+ Method parameters. +*/

typedef struct VgraphSeparateGpParam_ {
  INT                       passnbr;              /*+ Number of passes to do +*/
} VgraphSeparateGpParam;

/*+ Complementary vertex structure. +*/

typedef struct VgraphSeparateGpVertex_ {
  Gnum                      passnum;              /*+ Number of pass when vertex selected   +*/
  Gnum                      distval;              /*+ Current distance from diameter vertex +*/
} VgraphSeparateGpVertex;

/*+ Neighbor queue. +*/

typedef struct VgraphSeparateGpQueue_ {
  Gnum                      headnum;              /*+ Head of distance queue  +*/
  Gnum                      tailnum;              /*+ Tail of distance queue  +*/
  Gnum * restrict           queutab;              /*+ Array of queue elements +*/
} VgraphSeparateGpQueue;

/*
**  The function prototypes.
*/

#ifndef VGRAPH_SEPARATE_GP
#define static
#endif

int                         vgraphSeparateGp    (Vgraph * restrict const, const VgraphSeparateGpParam * restrict const);

#undef static

/*
**  The macro definitions.
*/

#define vgraphSeparateGpQueueFlush(queue) ((queue)->headnum = (queue)->tailnum = 0)
#define vgraphSeparateGpQueueEmpty(queue) ((queue)->headnum <= (queue)->tailnum)
#define vgraphSeparateGpQueuePut(queue,vnum) ((queue)->queutab[(queue)->headnum ++] = (vnum))
#define vgraphSeparateGpQueueGet(queue) ((queue)->queutab[(queue)->tailnum ++])

==> scotch_6.0.9.orig.tar.gz: scotch_6.0.9/src/libscotch/vgraph_separate_gp.h <==
/* Copyright 2004,2007,2010,2018 IPB, Universite de Bordeaux, INRIA & CNRS
**
** This file is part of the Scotch software package for static mapping,
** graph partitioning and sparse matrix ordering.
**
** This software is governed by the CeCILL-C license under French law
** and abiding by the rules of distribution of free software. You can
** use, modify and/or redistribute the software under the terms of the
** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
** URL: "http://www.cecill.info".
** 
** As a counterpart to the access to the source code and rights to copy,
** modify and redistribute granted by the license, users are provided
** only with a limited warranty and the software's author, the holder of
** the economic rights, and the successive licensors have only limited
** liability.
** 
** In this respect, the user's attention is drawn to the risks associated
** with loading, using, modifying and/or developing or reproducing the
** software by the user in light of its specific status of free software,
** that may mean that it is complicated to manipulate, and that also
** therefore means that it is reserved for developers and experienced
** professionals having in-depth computer knowledge. Users are therefore
** encouraged to load and test the software's suitability as regards
** their requirements in conditions enabling the security of their
** systems and/or data to be ensured and, more generally, to use and
** operate it in the same conditions as regards security.
** 
** The fact that you are presently reading this means that you have had
** knowledge of the CeCILL-C license and that you accept its terms.
*/
/************************************************************/
/**                                                        **/
/**   NAME       : vgraph_separate_gp.h                    **/
/**                                                        **/
/**   AUTHOR     : Francois PELLEGRINI                     **/
/**                                                        **/
/**   FUNCTION   : These lines are the data declaration    **/
/**                for the Gibbs, Poole, and Stockmeyer    **/
/**                graph separation algorithm.             **/
/**                                                        **/
/**   DATES      : # Version 4.0  : from : 14 may 2004     **/
/**                                 to     17 may 2004     **/
/**                # Version 5.1  : from : 04 nov 2010     **/
/**                                 to     04 nov 2010     **/
/**                # Version 6.0  : from : 30 apr 2018     **/
/**                                 to   : 30 apr 2018     **/
/**                                                        **/
/************************************************************/

/*
**  The type and structure definitions.
*/

/*+ Method parameters. +*/

typedef struct VgraphSeparateGpParam_ {
  INT                       passnbr;              /*+ Number of passes to do +*/
} VgraphSeparateGpParam;

/*+ Complementary vertex structure. +*/

typedef struct VgraphSeparateGpVertex_ {
  Gnum                      passnum;              /*+ Number of pass when vertex selected   +*/
  Gnum                      distval;              /*+ Current distance from diameter vertex +*/
} VgraphSeparateGpVertex;

/*+ Neighbor queue. +*/

typedef struct VgraphSeparateGpQueue_ {
  Gnum                      headnum;              /*+ Head of distance queue  +*/
  Gnum                      tailnum;              /*+ Tail of distance queue  +*/
  Gnum *                    queutab;              /*+ Array of queue elements +*/
} VgraphSeparateGpQueue;

/*
**  The function prototypes.
*/

int                         vgraphSeparateGp    (Vgraph * restrict const, const VgraphSeparateGpParam * restrict const);

/*
**  The macro definitions.
*/

#define vgraphSeparateGpQueueFlush(queue) ((queue)->headnum = (queue)->tailnum = 0)
#define vgraphSeparateGpQueueEmpty(queue) ((queue)->headnum <= (queue)->tailnum)
#define vgraphSeparateGpQueuePut(queue,vnum) ((queue)->queutab[(queue)->headnum ++] = (vnum))
#define vgraphSeparateGpQueueGet(queue) ((queue)->queutab[(queue)->tailnum ++])
